==> dde-launcher_4.4.5.5.orig.tar.xz: dde-launcher-4.4.5.5/translations/dde-launcher_hi_IN.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="hi_IN" version="2.1">
<context>
    <name>AppsManager</name>
    <message>
        <source>No search results</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Internet</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Chat</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Music</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Video</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Graphics</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Game</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Office</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Reading</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Development</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>System</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Others</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>FullScreenFrame</name>
    <message>
        <source>Are you sure to uninstall %1 ?</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Cancel</source>
        <translation>रद्द करो</translation>
    </message>
    <message>
        <source>Confirm</source>
        <translation>पुष्टि</translation>
    </message>
</context>
<context>
    <name>MenuWorker</name>
    <message>
        <source>Remove from desktop</source>
        <translation>डेस्कटॉप से हटाएं </translation>
    </message>
    <message>
        <source>Remove from dock</source>
        <translation>डॉक से हटाएं </translation>
    </message>
    <message>
        <source>Uninstall</source>
        <translation>स्थापना रद्द करें</translation>
    </message>
    <message>
        <source>Open by proxy</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Disable display scaling</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Open</source>
        <translation>खोलो</translation>
    </message>
    <message>
        <source>Send to desktop</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Send to dock</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Remove from startup</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Add to startup</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>MiniCategoryWidget</name>
    <message>
        <source>All Apps</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Internet</source>
        <translation>इंटरनेट</translation>
    </message>
    <message>
        <source>Chat</source>
        <translation>वार्तालाप</translation>
    </message>
    <message>
        <source>Music</source>
        <translation>संगीत</translation>
    </message>
    <message>
        <source>Video</source>
        <translation>वीडियो</translation>
    </message>
    <message>
        <source>Graphics</source>
        <translation>ग्राफिक्स</translation>
    </message>
    <message>
        <source>Game</source>
        <translation>गेम</translation>
    </message>
    <message>
        <source>Office</source>
        <translation>कार्यालय</translation>
    </message>
    <message>
        <source>Reading</source>
        <translation>पढ़ें</translation>
    </message>
    <message>
        <source>Development</source>
        <translation>विकास</translation>
    </message>
    <message>
        <source>System</source>
        <translation>प्रणाली</translation>
    </message>
    <message>
        <source>Others</source>
        <translation>अन्य</translation>
    </message>
</context>
<context>
    <name>MiniFrame</name>
    <message>
        <source>Are you sure to uninstall %1 ?</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>All dependencies will be removed together</source>
        <translation>सभी अनियमितता को एक साथ हटा दिया जाएगा </translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>रद्द करो</translation>
    </message>
    <message>
        <source>Confirm</source>
        <translation>पुष्टि</translation>
    </message>
</context>
<context>
    <name>MiniFrameBottomBar</name>
    <message>
        <source>Computer</source>
        <translation>कंप्यूटर</translation>
    </message>
    <message>
        <source>Documents</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Videos</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Music</source>
        <translation>संगीत</translation>
    </message>
    <message>
        <source>Pictures</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Downloads</source>
        <translation>डाउनलोड</translation>
    </message>
    <message>
        <source>Lock</source>
        <translation>अवरोधित</translation>
    </message>
    <message>
        <source>Logout</source>
        <translation>लॉग आउट करें </translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Suspend</source>
        <translation>निलंबित</translation>
    </message>
    <message>
        <source>Shutdown</source>
        <translation>शटडाउन </translation>
    </message>
    <message>
        <source>Back</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>MiniFrameNavigation</name>
    <message>
        <source>Computer</source>
        <translation>कंप्यूटर</translation>
    </message>
    <message>
        <source>Music</source>
        <translation>संगीत</translation>
    </message>
    <message>
        <source>Shutdown</source>
        <translation>शटडाउन </translation>
    </message>
    <message>
        <source>Lock</source>
        <translation>अवरोधित</translation>
    </message>
    <message>
        <source>Logout</source>
        <translation>लॉग आउट करें </translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Suspend</source>
        <translation>निलंबित</translation>
    </message>
    <message>
        <source>Back</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Documents</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Videos</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Pictures</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Downloads</source>
        <translation>डाउनलोड</translation>
    </message>
</context>
<context>
    <name>MiniFrameRightBar</name>
    <message>
        <source>Computer</source>
        <translation>कंप्यूटर</translation>
    </message>
    <message>
        <source>Music</source>
        <translation>संगीत</translation>
    </message>
    <message>
        <source>Downloads</source>
        <translation>डाउनलोड</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>मैनुअल </translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>व्यवस्था</translation>
    </message>
    <message>
        <source>Shutdown</source>
        <translation>शटडाउन </translation>
    </message>
    <message>
        <source>Videos</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Pictures</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Documents</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>MiniFrameSwitchBtn</name>
    <message>
        <source>All Categories</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Back</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>SearchLineEdit</name>
    <message>
        <source>Search</source>
        <translation>खोज</translation>
    </message>
</context>
<context>
    <name>WindowedFrame</name>
    <message>
        <source>Are you sure to uninstall %1 ?</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Cancel</source>
        <translation>रद्द करो</translation>
    </message>
    <message>
        <source>Confirm</source>
        <translation>पुष्टि</translation>
    </message>
</context>
</TS>

==> dde-launcher_5.0.14.orig.tar.xz: dde-launcher-5.0.14/translations/dde-launcher_hi_IN.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="hi_IN" version="2.1">
<context>
    <name>AppsManager</name>
    <message>
        <source>No search results</source>
        <translation>खोज का कोई परिणाम नहीं मिला</translation>
    </message>
    <message>
        <source>Internet</source>
        <translation>इंटरनेट</translation>
    </message>
    <message>
        <source>Chat</source>
        <translation>वार्तालाप</translation>
    </message>
    <message>
        <source>Music</source>
        <translation>संगीत</translation>
    </message>
    <message>
        <source>Video</source>
        <translation>वीडियो</translation>
    </message>
    <message>
        <source>Graphics</source>
        <translation>ग्राफ़िक्स</translation>
    </message>
    <message>
        <source>Office</source>
        <translation>कार्यालय</translation>
    </message>
    <message>
        <source>Reading</source>
        <translation>पठन</translation>
    </message>
    <message>
        <source>Development</source>
        <translation>सॉफ्टवेयर विकास</translation>
    </message>
    <message>
        <source>System</source>
        <translation>सिस्टम </translation>
    </message>
    <message>
        <source>Games</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Other</source>
        <translation>अन्य</translation>
    </message>
</context>
<context>
    <name>FullScreenFrame</name>
    <message>
        <source>Cancel</source>
        <translation>रद्द करें</translation>
    </message>
    <message>
        <source>Confirm</source>
        <translation>पुष्टि करें </translation>
    </message>
    <message>
        <source>Are you sure you want to uninstall %1 ?</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>MenuWorker</name>
    <message>
        <source>Remove from desktop</source>
        <translation>डेस्कटॉप से हटाएँ</translation>
    </message>
    <message>
        <source>Remove from dock</source>
        <translation>डॉक से हटाएँ</translation>
    </message>
    <message>
        <source>Uninstall</source>
        <translation>हटाएँ</translation>
    </message>
    <message>
        <source>Disable display scaling</source>
        <translation>डिस्प्ले मापन निष्क्रिय करें</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>खोलें</translation>
    </message>
    <message>
        <source>Send to desktop</source>
        <translation>डेस्कटॉप पर भेजें</translation>
    </message>
    <message>
        <source>Send to dock</source>
        <translation>डॉक पर भेजें</translation>
    </message>
    <message>
        <source>Remove from startup</source>
        <translation>स्टार्टअप से हटाएँ</translation>
    </message>
    <message>
        <source>Add to startup</source>
        <translation>स्टार्टअप में जोड़ें</translation>
    </message>
    <message>
        <source>Use a proxy</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>MiniCategoryWidget</name>
    <message>
        <source>All Apps</source>
        <translation>सभी अनुप्रयोग</translation>
    </message>
    <message>
        <source>Internet</source>
        <translation>इंटरनेट</translation>
    </message>
    <message>
        <source>Chat</source>
        <translation>वार्तालाप</translation>
    </message>
    <message>
        <source>Music</source>
        <translation>संगीत</translation>
    </message>
    <message>
        <source>Video</source>
        <translation>वीडियो</translation>
    </message>
    <message>
        <source>Graphics</source>
        <translation>ग्राफ़िक्स</translation>
    </message>
    <message>
        <source>Game</source>
        <translation>खेल</translation>
    </message>
    <message>
        <source>Office</source>
        <translation>कार्यालय</translation>
    </message>
    <message>
        <source>Reading</source>
        <translation>पठन</translation>
    </message>
    <message>
        <source>Development</source>
        <translation>सॉफ्टवेयर विकास</translation>
    </message>
    <message>
        <source>System</source>
        <translation>सिस्टम </translation>
    </message>
    <message>
        <source>Others</source>
        <translation>अन्य</translation>
    </message>
</context>
<context>
    <name>MiniFrameBottomBar</name>
    <message>
        <source>Computer</source>
        <translation>कंप्यूटर</translation>
    </message>
    <message>
        <source>Documents</source>
        <translation>दस्तावेज़</translation>
    </message>
    <message>
        <source>Videos</source>
        <translation>वीडियो</translation>
    </message>
    <message>
        <source>Music</source>
        <translation>संगीत</translation>
    </message>
    <message>
        <source>Pictures</source>
        <translation>चित्र</translation>
    </message>
    <message>
        <source>Downloads</source>
        <translation>डाउनलोड</translation>
    </message>
    <message>
        <source>Lock</source>
        <translation>लॉक स्क्रीन</translation>
    </message>
    <message>
        <source>Logout</source>
        <translation>लॉग आउट करें </translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>पुनः आरंभ करें</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>निलंबित</translation>
    </message>
    <message>
        <source>Shutdown</source>
        <translation>शटडाउन </translation>
    </message>
    <message>
        <source>Back</source>
        <translation>वापस</translation>
    </message>
</context>
<context>
    <name>MiniFrameNavigation</name>
    <message>
        <source>Computer</source>
        <translation>कंप्यूटर</translation>
    </message>
    <message>
        <source>Music</source>
        <translation>संगीत</translation>
    </message>
    <message>
        <source>Shutdown</source>
        <translation>शटडाउन </translation>
    </message>
    <message>
        <source>Lock</source>
        <translation>अवरोधित</translation>
    </message>
    <message>
        <source>Logout</source>
        <translation>लॉगआउट करें</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>पुनः आरंभ करें</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>स्थगित करें</translation>
    </message>
    <message>
        <source>Back</source>
        <translation>वापस</translation>
    </message>
    <message>
        <source>Documents</source>
        <translation>दस्तावेज़</translation>
    </message>
    <message>
        <source>Videos</source>
        <translation>वीडियो</translation>
    </message>
    <message>
        <source>Pictures</source>
        <translation>चित्र</translation>
    </message>
    <message>
        <source>Downloads</source>
        <translation>डाउनलोड</translation>
    </message>
</context>
<context>
    <name>MiniFrameRightBar</name>
    <message>
        <source>Computer</source>
        <translation>कंप्यूटर</translation>
    </message>
    <message>
        <source>Music</source>
        <translation>संगीत</translation>
    </message>
    <message>
        <source>Downloads</source>
        <translation>डाउनलोड</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>मैनुअल </translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>सेटिंग्स</translation>
    </message>
    <message>
        <source>Videos</source>
        <translation>वीडियो</translation>
    </message>
    <message>
        <source>Pictures</source>
        <translation>चित्र</translation>
    </message>
    <message>
        <source>Documents</source>
        <translation>दस्तावेज़</translation>
    </message>
    <message>
        <source>Power</source>
        <translation>पॉवर</translation>
    </message>
</context>
<context>
    <name>MiniFrameSwitchBtn</name>
    <message>
        <source>All Categories</source>
        <translation>सभी श्रेणियाँ</translation>
    </message>
    <message>
        <source>Back</source>
        <translation>वापस</translation>
    </message>
</context>
<context>
    <name>SearchLineEdit</name>
    <message>
        <source>Search</source>
        <translation>खोजें</translation>
    </message>
</context>
<context>
    <name>WindowedFrame</name>
    <message>
        <source>Cancel</source>
        <translation>रद्द करें</translation>
    </message>
    <message>
        <source>Confirm</source>
        <translation>पुष्टि करें </translation>
    </message>
    <message>
        <source>Are you sure you want to uninstall %1 ?</source>
        <translation type="unfinished"/>
    </message>
</context>
</TS>
